@@ -2,7 +2,7 @@
 
 package Tapper::Schema::TestrunDB::Result::TestrunScheduling;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Schema::TestrunDB::Result::TestrunScheduling::VERSION = '5.0.8';
+$Tapper::Schema::TestrunDB::Result::TestrunScheduling::VERSION = '5.0.9';
 # ABSTRACT: Tapper - Containing informations for an executed testrun
 
 use YAML::Syck;
@@ -39,6 +39,18 @@ __PACKAGE__->has_many  ( requested_hosts    => "${basepkg}::TestrunRequestedHost
 
 
 
+sub update_content {
+        my ($self, $args) =@_;
+
+        $self->queue_id      ( $args->{queue_id}    ) if $args->{queue_id};
+        $self->host_id       ( $args->{host_id}     ) if $args->{host_id};
+        $self->status        ( $args->{status}      ) if $args->{status};
+        $self->auto_rerun    ( $args->{auto_rerun}  ) if $args->{auto_rerun};
+        $self->update;
+        return $self->id;
+}
+
+
 sub mark_as_running
 {
         my ($self) = @_;
@@ -109,6 +121,10 @@ __END__
 
 Tapper::Schema::TestrunDB::Result::TestrunScheduling - Tapper - Containing informations for an executed testrun
 
+=head2 update_content
+
+Update content from given params.
+
 =head2 mark_as_running
 
 Mark a testrun as currently I<running>.
@@ -137,7 +153,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2017 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
